@@ -42,11 +42,6 @@
 #include <string.h>
 #include <unistd.h>
 
-#ifdef G_OS_WIN32
-#include <io.h>
-#include <windows.h>
-#endif
-
 /****************** ORBit-specific stuff ****************/
 
 #include <orbit/orbit.h>
@@ -65,6 +60,7 @@ gboolean bonobo_activation_private = FALSE;
 #error Must build as a DLL
 #endif
 
+#include <io.h>
 #include <windows.h>
 #include <mbstring.h>
 
@@ -349,6 +345,7 @@ bonobo_activation_object_directory_get (const char *username,
 static int   bonobo_activation_ior_fd = 1;
 static char *bonobo_activation_activate_iid = NULL;
 
+#ifndef BONOBO_DISABLE_DEPRECATED_SOURCE
 struct poptOption bonobo_activation_popt_options[] = {
         { NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL },
         { "oaf-ior-fd", '\0', POPT_ARG_INT, &bonobo_activation_ior_fd, 0,
@@ -359,16 +356,7 @@ struct poptOption bonobo_activation_popt_options[] = {
           N_("Prevent registering of server with OAF"), NULL },
         { NULL }
 };
-
-static const GOptionEntry bonobo_activation_goption_options[] = {
-        { "oaf-ior-fd", '\0', 0,  G_OPTION_ARG_INT, &bonobo_activation_ior_fd, 
-          N_("File descriptor to print IOR on"), N_("FD") },
-        { "oaf-activate-iid", '\0', 0, G_OPTION_ARG_STRING, &bonobo_activation_activate_iid, 
-          N_("IID to activate"), "IID" },
-        { "oaf-private", '\0', 0, G_OPTION_ARG_NONE, &bonobo_activation_private, 
-          N_("Prevent registering of server with OAF"), NULL },
-        { NULL }
-};
+#endif /* BONOBO_DISABLE_DEPRECATED_SOURCE */
 
 static void
 init_gettext (gboolean bind_codeset)
@@ -395,12 +383,21 @@ init_gettext (gboolean bind_codeset)
 GOptionGroup *
 bonobo_activation_get_goption_group (void)
 {
+	const GOptionEntry bonobo_activation_goption_options[] = {
+		{ "oaf-ior-fd", '\0', 0,  G_OPTION_ARG_INT, &bonobo_activation_ior_fd,
+		  N_("File descriptor to print IOR on"), N_("FD") },
+		{ "oaf-activate-iid", '\0', 0, G_OPTION_ARG_STRING, &bonobo_activation_activate_iid,
+		  N_("IID to activate"), "IID" },
+		{ "oaf-private", '\0', 0, G_OPTION_ARG_NONE, &bonobo_activation_private,
+		  N_("Prevent registering of server with OAF"), NULL },
+		{ NULL }
+	};
 	GOptionGroup *group;
 
 	init_gettext (TRUE);
 
 	group = g_option_group_new ("bonobo-activation",
-				    N_("Bonobo Activation"),
+				    N_("Bonobo Activation options:"),
 				    N_("Show Bonobo Activation options"),
 				    NULL, NULL);
 	g_option_group_set_translation_domain (group, GETTEXT_PACKAGE);
@@ -496,7 +493,7 @@ bonobo_activation_is_initialized (void)
 	return is_initialized;
 }
 
-
+#ifndef BONOBO_DISABLE_DEPRECATED_SOURCE
 /**
  * bonobo_activation_get_popt_table_name:
  *
@@ -511,7 +508,7 @@ bonobo_activation_get_popt_table_name (void)
 	init_gettext (FALSE);
 	return _("Bonobo activation options");
 }
-
+#endif /* BONOBO_DISABLE_DEPRECATED_SOURCE */
 
 /**
  * bonobo_activation_init:
@@ -639,7 +636,7 @@ bonobo_activation_orb_init (int *argc, char **argv)
  * bonobo_activation_debug_shutdown:
  * 
  *   A debugging function to shutdown the ORB and process
- * any reference count leaks that may have occured.
+ * any reference count leaks that may have occurred.
  * 
  * Return value: FALSE if there were leaks detected, else TRUE
  **/
