@@ -26,6 +26,7 @@
 #include <bonobo/bonobo-types.h>
 #include <bonobo/bonobo-private.h>
 #include <bonobo/bonobo-debug.h>
+#include <bonobo/bonobo-i18n.h>
 
 /* We need decent ORB cnx. flushing on shutdown to make this work */
 #undef ASYNC_UNREFS
@@ -621,13 +622,10 @@ bonobo_object_query_local_interface (BonoboObject *object,
 				     const char   *repo_id)
 {
 	GList             *l;
-	CORBA_Object       corba_retval = CORBA_OBJECT_NIL;
 	CORBA_Environment  ev;
 
 	g_return_val_if_fail (BONOBO_IS_OBJECT (object), NULL);
 
-	corba_retval = CORBA_OBJECT_NIL;
-
 	CORBA_exception_init (&ev);
 
 	for (l = object->priv->ao->objs; l; l = l->next){
@@ -779,8 +777,9 @@ do_corba_setup_T (BonoboObject *object)
 		}
 		xklass->poa_init_fn ((PortableServer_Servant) &object->servant, ev);
 		if (BONOBO_EX (ev)) {
-			g_warning ("Exception initializing servant '%s'",
-				   bonobo_exception_get_text (ev));
+			char *text = bonobo_exception_get_text (ev);
+			g_warning ("Exception initializing servant '%s'", text);
+			g_free (text);
 			return;
 		}
 	}
